@@ -274,4 +274,14 @@ class DNSLine(ExpiredValueObject):
 
 class ServiceType(ExpiredValueObject):
     def __init__(self, value):
-        super().__init__(value, None)
\ No newline at end of file
+        super().__init__(value, None)
+
+class Time(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class PodStatus(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+    def is_running(self):
+        return 'Running' in self.value
\ No newline at end of file
